"use strict";
this.name        = "illegal_goods_missions";
this.author      = "capt murphy";
this.copyright   = "2011 capt murphy";
this.licence     = "CC BY-NC-SA 3.0";
this.description = "Missions worldscript for illegal_goods_tweak.";

// "my son" must always be in array position 1 for a particular mission
this._rescueeArray = ["me", "my son", "my daughter", "my partner", "my spouse", "my brother", "my sister", "my father", "my mother"];

//======================================================================================================================
// clears up missionVariables from previous versions,
this.startUp = function() {
	if (missionVariables.ig_pendingmission === "no") {delete missionVariables.ig_pendingmission; delete missionVariables.ig_rescuetime; delete missionVariables.ig_missionlaunchtime; delete missionVariables.ig_rescuelocation;}
	if (missionVariables.ig_currentmission === "no"){this.$ig_cleanupmissionvariables();}
	delete missionVariables.ig_rescuelocation1;
	if (!worldScripts.snoopers && !worldScripts.GNN) {
		delete this.shipExitedWitchSpace;
	}
}

//======================================================================================================================
// existing missions cleared on galactic jump
this.playerEnteredNewGalaxy = function() {
    delete missionVariables.ig_pendingmission;
	delete missionVariables.ig_rescuelocation;
	delete missionVariables.ig_rescuetime;
	delete missionVariables.ig_missionlaunchtime;
    this.$ig_cleanupmissionvariables();
	mission.setInstructionsKey (null, "illegal_goods_missions");
}

//======================================================================================================================
// used at startUp to clean old missionVariables and at the end of a mission.
this.$ig_cleanupmissionvariables = function() {
	delete missionVariables.ig_currentmission;
	delete missionVariables.ig_contactname;
	delete missionVariables.ig_rescuee;
	delete missionVariables.ig_rescuedwhen;
	delete missionVariables.ig_missionsystem;
	delete missionVariables.ig_missionsystemname;
	delete missionVariables.ig_rescuelocationcurrent;
	delete missionVariables.ig_missionreward;
	delete missionVariables.ig_slaverbasedestroyed;
	delete missionVariables.ig_special5end;
	delete missionVariables.ig_special5slavecount;
}

//======================================================================================================================
this.missionScreenOpportunity = function() { // don't run if save anywhere scripted dock.
	if (player.ship.docked && player.ship.dockedStation.isMainStation) {
		this.$igmissionsetup();
		this.$igmissionfinish();
		delete missionVariables.ig_special5end; // needed to allow mission screen to run after handing over slaves at end of this mission.
	}
}

// send a news item out after the slaver base is destroyed
this.shipExitedWitchspace = function() {
	if (missionVariables.ig_slaverbasenewsitem && global.clock.seconds > parseInt(missionVariables.ig_slaverbasenewsitem)) {
		var news = {ID:this.name,
			Message:expandMissionText("special5_newsitem"),
			Agency:1,
			Priority:1
		};
		var g = worldScripts.GNN;
		if (g) g._insertNews(news);
		if (!g) {
			var w = worldScripts.snoopers;
			if (w) w.insertNews(news);
		}
		delete missionVariables.ig_slaverbasenewsitem;
		delete missionVariables.ig_slaverbasesystem;
	}
}

//======================================================================================================================
// if pending mission is true, mission launch time has passed and no current mission set up new mission,
this.$igmissionsetup = function() {
	if (missionVariables.ig_pendingmission && !missionVariables.ig_currentmission && clock.days >= missionVariables.ig_missionlaunchtime) {
		if (Math.random() < 0.4) {
			this.$igspecialmissionsetup(); // set up one of 4 special missions
		} else {
			this.$igstandardmissionsetup(); // set up standard mission.
		}
		if (missionVariables.ig_currentmission) { // possible that no mission results from set-up
			mission.runScreen({screenID: "igt_aimission", title: "Message from Amnesty Intergalactic", messageKey: "offer_mission"});
			if (missionVariables.ig_currentmission == "standard") {
				// email system interface
				var w = worldScripts.EmailSystem;
				if (w) {
					w.$createEmail({sender:"Amnesty Intergalactic",
						subject:"Meeting request",
						date:global.clock.seconds,
						message:expandMissionText("offer_mission"),
						isRead:true
					});
				}
			}
			delete missionVariables.ig_pendingmission;
			delete missionVariables.ig_missionlaunchtime;
			delete missionVariables.ig_rescuedwhen;
			delete missionVariables.ig_rescuetime;
			delete missionVariables.ig_rescuelocation;
		}
	}
}

//======================================================================================================================
// sets up standard mission.
this.$igstandardmissionsetup = function() {

	missionVariables.ig_contactname = (randomName() + " " + randomName());

	var rescuee = (Math.floor(Math.random() * this._rescueeArray.length));
	missionVariables.ig_rescuee = this._rescueeArray[rescuee];
	missionVariables.ig_rescuedwhen = (clock.days - missionVariables.ig_rescuetime);

	var targetsystemsID = new Array;
	var targetsystems = SystemInfo.systemsInRange(35);
	var potentialmissionsystem;

    if (targetsystems.length > 0) {
		var counter = 0;
		for (counter = 0; counter < targetsystems.length; counter++) {
			targetsystemsID[counter] = targetsystems[counter].systemID;
		}
		var thisGalaxy = system.info.galaxyID;
		var thisSystem = system.ID;
		// selects a system at random from systems within 35 light years of current system. If selected system is within 7 light years, or is post nova, or there is no possible route to the system will try and select another. If fails to find a suitable system within 100 iterations, mission is cancelled.
		counter = 0
		while (counter < 100) {
			potentialmissionsystem = targetsystemsID[(Math.floor(Math.random() * targetsystemsID.length))];
			if (!System.infoForSystem(thisGalaxy, thisSystem).routeToSystem(System.infoForSystem(thisGalaxy, potentialmissionsystem)) ||
				System.infoForSystem(thisGalaxy, potentialmissionsystem).sun_gone_nova ||
				System.infoForSystem(thisGalaxy, thisSystem).distanceToSystem(System.infoForSystem(thisGalaxy, potentialmissionsystem)) < 7) {
					potentialmissionsystem = -1;
			}
			counter++;
			if (potentialmissionsystem !== -1) {break;}
		}
	}

	if (potentialmissionsystem === -1) {return;}

	missionVariables.ig_missionsystem = potentialmissionsystem;
	missionVariables.ig_missionsystemname = System.infoForSystem(thisGalaxy, potentialmissionsystem).name;

	var distance = System.infoForSystem(thisGalaxy, thisSystem).routeToSystem(System.infoForSystem(system.info.galaxyID, potentialmissionsystem)).distance;

	missionVariables.ig_missionreward = (500 + (Math.floor(distance / 7) * 250));
	mission.markSystem({system:potentialmissionsystem, name:"ig_mission"});
	mission.setInstructionsKey ("mission_summary", "illegal_goods_missions");
	missionVariables.ig_currentmission = "standard";
	missionVariables.ig_rescuelocationcurrent = missionVariables.ig_rescuelocation;
}

//======================================================================================================================
// sets up special mission - runs standard mission set-up then overwrites some missionvariables.
this.$igspecialmissionsetup = function() {
	this.$igstandardmissionsetup();
	if (!missionVariables.ig_currentmission) {return;}

	var ig_switchvar =  (Math.floor(Math.random() * 4));

	switch(ig_switchvar) {
		case 0:
			missionVariables.ig_currentmission = "special1";
			missionVariables.ig_rescuee = this._rescueeArray[1];
			break;
		case 1:
			if (player.ship.equipmentStatus("EQ_IG_INSURANCE") !== "EQUIPMENT_OK") {
				missionVariables.ig_currentmission = "special2";
			}
			break;
		case 2:
			if (player.ship.equipmentStatus("EQ_IG_LEGAL_HACK") !== "EQUIPMENT_OK") {
				missionVariables.ig_currentmission = "special3";
			}
			break;
		case 3:
			missionVariables.ig_currentmission = "special4";
	}
}

//======================================================================================================================
// checks for current mission and correct system before running mission success screens.
this.$igmissionfinish = function () {
	if (missionVariables.ig_currentmission && system.info.systemID === missionVariables.ig_missionsystem) {
		switch (missionVariables.ig_currentmission) {
			case "standard":
				player.credits += missionVariables.ig_missionreward;
				mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
				mission.setInstructionsKey (null, "illegal_goods_missions");
				var w = worldScripts.EmailSystem;
				if (!w) {
					mission.runScreen({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_noemail"});
				} else {
					mission.runScreen({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_withemail"});
					w.$createEmail({sender:missionVariables.ig_contactname,
						subject:"Eternal Gratitude",
						date:global.clock.seconds,
						message:expandMissionText("end_mission_email")
					});
				}
				clock.addSeconds (43200);
				this.$ig_cleanupmissionvariables();
				break;
			case "special1":
				mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special1", choicesKey: "ship_visit_agree"}, this.$ig_shipvisitchoice);
				break;
			case "special2":
				player.ship.awardEquipment("EQ_IG_INSURANCE");
				mission.setInstructionsKey (null, "illegal_goods_missions");
				mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
				mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special2"});
				this.$ig_cleanupmissionvariables();
				break;
			case "special3":
				player.ship.awardEquipment("EQ_IG_LEGAL_HACK");
				mission.setInstructionsKey (null, "illegal_goods_missions");
				mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
				mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special3"});
				this.$ig_cleanupmissionvariables();
				break;
			case "special4":
				player.credits += missionVariables.ig_missionreward;
				mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special4", choicesKey: "special4_mission_agree"}, this.$ig_special4choice);
				break;
			case "special5":
				if (missionVariables.ig_slaverbasedestroyed && missionVariables.ig_special5end !== "not yet") {
					mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special5", choicesKey: "special5_slaves_left"}, this.$ig_special5choice);
				}
		}
	}
}

//======================================================================================================================
this.$ig_shipvisitchoice = function(choice) {
	if (choice === "1_VISITAGREE") {
		player.credits += missionVariables.ig_missionreward;
		mission.setInstructionsKey (null, "illegal_goods_missions");
		mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
		clock.addSeconds (43200);
		mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special1a"});
		player.ship.awardEquipment("EQ_TRUMBLE");
	} else {
		missionVariables.ig_missionreward = (missionVariables.ig_missionreward / 2);
		player.credits += missionVariables.ig_missionreward;
		mission.setInstructionsKey (null, "illegal_goods_missions");
		mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
		mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special1b"});
	}
	this.$ig_cleanupmissionvariables();
}

//======================================================================================================================
this.$ig_special4choice = function(choice) {
	if (choice === "1_AGREESPECIAL5") {
		missionVariables.ig_currentmission = "special5"
		mission.setInstructionsKey ("special5_instructions", "illegal_goods_missions");
		missionVariables.ig_special5slavecount = 0;
		mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special4b"});
	} else {
		mission.setInstructionsKey (null, "illegal_goods_missions");
		mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
		mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special4a"});
		this.$ig_cleanupmissionvariables();
	}
}

//======================================================================================================================
this.$ig_special5choice = function(choice) {
	if(choice === "1_YESSLAVES") {
		missionVariables.ig_special5end = "not yet";
		mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special5b"});
	} else {
		mission.setInstructionsKey (null, "illegal_goods_missions");
		mission.unmarkSystem({system:system.info.systemID, name:"ig_mission"});
		missionVariables.ig_missionreward = (1000 + (missionVariables.ig_special5slavecount * 50));
		mission.runScreen ({screenID:"igt_endmission", title: "Eternal Gratitude.", messageKey: "end_mission_special5a"});
		player.credits += missionVariables.ig_missionreward;
		this.$ig_cleanupmissionvariables();
	}
}

//======================================================================================================================
// used in special5 mission
this.systemWillPopulate = function() {

	// we put the slaver base in regardless of whether the player chooses to access the mission
	// it's on the other side of the sun, so they are unlikely to find it without notification
	// if they do, well, that's just a bonus for the player
	if ((missionVariables.ig_currentmission === "special4" || missionVariables.ig_currentmission === "special5") &&
		system.info.systemID === missionVariables.ig_missionsystem &&
		system.countShipsWithRole("slaver_base") === 0 &&
		!missionVariables.ig_slaverbasedestroyed) {

		// set the position of the base
		//log(this.name, "Adding slaver base to system");
		var position = Vector3D(0, 0, 1.2 + Math.random() * 0.2).fromCoordinateSystem("psu");
		// add base with populator
		system.setPopulator("slaver base", {
			callback: function(pos) {
				//log(this.name, "adding...");
				var sb = system.addShips("slaver_base", 1, pos);
				//log(this.name, "result: " + sb);
				// adjust properties of slaver base
				if (sb.length > 0) sb[0].suppressArrivalReports = true;
				if (!sb || sb.length == 0) log(this.name, "ERROR - slaser base not created!");
			}.bind(this),
			location:"COORDINATES",
			coordinates:position});

		// add some asteroids around the base
		system.setPopulator("sb_asteroid", {
			callback: function(pos) {
				system.addShips("asteroid", 8, pos, player.ship.scannerRange);
			}.bind(this),
			location:"COORDINATES",
			coordinates:position});

	}
}

//======================================================================================================================
// used for free maintenace equipment.
this.guiScreenChanged = function(to, from) {
	if(to === "GUI_SCREEN_EQUIP_SHIP" && player.ship.equipmentStatus("EQ_IG_INSURANCE") === "EQUIPMENT_OK") {
		this._ig_playercredits = player.credits;
	}
}

//======================================================================================================================
this.playerBoughtEquipment = function(equipment) {
	if(player.ship.equipmentStatus("EQ_IG_INSURANCE") === "EQUIPMENT_OK") {
		if(equipment === "EQ_RENOVATION") {
			player.credits = this._ig_playercredits;
			player.ship.removeEquipment("EQ_IG_INSURANCE");
			player.consoleMessage("TianveDirect Insurance Policy redeemed - No charge for Maintenance Overhaul",5);
		} else {
			this._ig_playercredits = player.credits;
		}
	}
}
